==> huaweicloudsdksmnglobal-3.1.141-py2.py3-none-any.whl: huaweicloudsdksmnglobal/v2/model/update_subscription_user_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateSubscriptionUserRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'group': 'list[str]'
    }

    attribute_map = {
        'name': 'name',
        'group': 'group'
    }

    def __init__(self, name=None, group=None):
        """UpdateSubscriptionUserRequestBody

        The model defined in huaweicloud sdk

        :param name: 订阅用户名称。
        :type name: str
        :param group: 订阅用户分组。每个订阅分组只能包含小写英文字母([a-z])、数字([0-9])、下划线(_)，下划线不能出现在开始或结尾，下划线不能连续出现，长度为1到32个字符。
        :type group: list[str]
        """
        
        

        self._name = None
        self._group = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if group is not None:
            self.group = group

    @property
    def name(self):
        """Gets the name of this UpdateSubscriptionUserRequestBody.

        订阅用户名称。

        :return: The name of this UpdateSubscriptionUserRequestBody.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdateSubscriptionUserRequestBody.

        订阅用户名称。

        :param name: The name of this UpdateSubscriptionUserRequestBody.
        :type name: str
        """
        self._name = name

    @property
    def group(self):
        """Gets the group of this UpdateSubscriptionUserRequestBody.

        订阅用户分组。每个订阅分组只能包含小写英文字母([a-z])、数字([0-9])、下划线(_)，下划线不能出现在开始或结尾，下划线不能连续出现，长度为1到32个字符。

        :return: The group of this UpdateSubscriptionUserRequestBody.
        :rtype: list[str]
        """
        return self._group

    @group.setter
    def group(self, group):
        """Sets the group of this UpdateSubscriptionUserRequestBody.

        订阅用户分组。每个订阅分组只能包含小写英文字母([a-z])、数字([0-9])、下划线(_)，下划线不能出现在开始或结尾，下划线不能连续出现，长度为1到32个字符。

        :param group: The group of this UpdateSubscriptionUserRequestBody.
        :type group: list[str]
        """
        self._group = group

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateSubscriptionUserRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdksmnglobal-3.1.144-py2.py3-none-any.whl: huaweicloudsdksmnglobal/v2/model/update_subscription_user_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateSubscriptionUserRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'group': 'list[str]'
    }

    attribute_map = {
        'name': 'name',
        'group': 'group'
    }

    def __init__(self, name=None, group=None):
        r"""UpdateSubscriptionUserRequestBody

        The model defined in huaweicloud sdk

        :param name: 订阅用户名称。
        :type name: str
        :param group: 订阅用户分组。每个订阅分组只能包含小写英文字母([a-z])、数字([0-9])、下划线(_)，下划线不能出现在开始或结尾，下划线不能连续出现，长度为1到32个字符。
        :type group: list[str]
        """
        
        

        self._name = None
        self._group = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if group is not None:
            self.group = group

    @property
    def name(self):
        r"""Gets the name of this UpdateSubscriptionUserRequestBody.

        订阅用户名称。

        :return: The name of this UpdateSubscriptionUserRequestBody.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        r"""Sets the name of this UpdateSubscriptionUserRequestBody.

        订阅用户名称。

        :param name: The name of this UpdateSubscriptionUserRequestBody.
        :type name: str
        """
        self._name = name

    @property
    def group(self):
        r"""Gets the group of this UpdateSubscriptionUserRequestBody.

        订阅用户分组。每个订阅分组只能包含小写英文字母([a-z])、数字([0-9])、下划线(_)，下划线不能出现在开始或结尾，下划线不能连续出现，长度为1到32个字符。

        :return: The group of this UpdateSubscriptionUserRequestBody.
        :rtype: list[str]
        """
        return self._group

    @group.setter
    def group(self, group):
        r"""Sets the group of this UpdateSubscriptionUserRequestBody.

        订阅用户分组。每个订阅分组只能包含小写英文字母([a-z])、数字([0-9])、下划线(_)，下划线不能出现在开始或结尾，下划线不能连续出现，长度为1到32个字符。

        :param group: The group of this UpdateSubscriptionUserRequestBody.
        :type group: list[str]
        """
        self._group = group

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateSubscriptionUserRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
